==> plasma-mediacenter-0.8.90.tar.bz2: plasma-mediacenter/browsingbackends/localfiles/localmusic/localmusicbackend.h <==
/***************************************************************************
 *   Copyright 2009 by Alessandro Diaferia <alediaferia@gmail.com>         *
 *                                                                                  *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/
#ifndef LOCALMUSICPACKAGE_H
#define LOCALMUSICPACKAGE_H

#include "../localfilesabstractbackend.h"

class LocalMusicBackend : public LocalFilesAbstractBackend
{
    Q_OBJECT
public:
    LocalMusicBackend(QObject *parent, const QVariantList &args);
    ~LocalMusicBackend();

protected:
    virtual void initModel();
};

#endif // LOCALMUSICPACKAGE_H

==> plasma-mediacenter-1.1.0.tar.bz2: plasma-mediacenter/browsingbackends/localfiles/localmusic/localmusicbackend.h <==
/***************************************************************************
 *   Copyright 2009 by Alessandro Diaferia <alediaferia@gmail.com>         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef LOCALMUSICBACKEND_H
#define LOCALMUSICBACKEND_H

#include "../localfilesabstractbackend.h"

class LocalMusicModel;
class LocalMusicBackend : public LocalFilesAbstractBackend
{
    Q_OBJECT
public:
    LocalMusicBackend(QObject *parent, const QVariantList &args);
    ~LocalMusicBackend();

protected:
    virtual void initModel();

private:
    LocalMusicModel *m_model;
};

#endif // LOCALMUSICBACKEND_H
